@@ -19,9 +19,9 @@
 #include <grantlee/metatype.h>
 #include <grantlee/templateloader.h>
 #else
-#include <KTextTemplate/context.h>
-#include <KTextTemplate/metatype.h>
-#include <KTextTemplate/templateloader.h>
+#include <KTextTemplate/Context>
+#include <KTextTemplate/MetaType>
+#include <KTextTemplate/TemplateLoader>
 #endif
 
 #include <Akonadi/Item>
