@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,10 +13,10 @@
 #include <grantlee/metatype.h>
 #include <grantlee/templateloader.h>
 #else
-#include <KTextTemplate/context.h>
-#include <KTextTemplate/engine.h>
-#include <KTextTemplate/metatype.h>
-#include <KTextTemplate/templateloader.h>
+#include <KTextTemplate/Context>
+#include <KTextTemplate/Engine>
+#include <KTextTemplate/MetaType>
+#include <KTextTemplate/TemplateLoader>
 #endif
 
 #include <QMetaProperty>
